.. _what:

What is exoplanet?
==================

*exoplanet* is a set of tools that provide the foundation for using
gradient-based inference algorithms for fitting exoplanets observed using
radial velocities or transits.
